@@ -15,6 +15,8 @@
 #include <KPluginInfo>
 #include <KPluginMetaData>
 
+#include <memory>
+
 #include "abstractrunner.h"
 #include "krunner_export.h"
 
@@ -338,6 +340,7 @@ public:
     QMimeData *mimeDataForMatch(const QString &matchId) const;
 #endif
 
+#if KRUNNER_ENABLE_DEPRECATED_SINCE(5, 85)
     /**
      * Returns a list of all known Runner implementations
      *
@@ -348,8 +351,17 @@ public:
      *                  registered to an application.
      * @return list of metadata of known runners
      * @since 5.72
+     * @deprecated Since 5.85, the concept of parent apps for runners is deprecated, use no-arg overload instead
      **/
-    static QVector<KPluginMetaData> runnerMetaDataList(const QString &parentApp = QString());
+    KRUNNER_DEPRECATED_VERSION(5, 85, "The concept of parent apps for runners is deprecated, use no-arg overload instead")
+    static QVector<KPluginMetaData> runnerMetaDataList(const QString &parentApp);
+#endif
+
+    /**
+     * @return metadata list of all known Runner implementations
+     * @since 5.72
+     */
+    static QVector<KPluginMetaData> runnerMetaDataList();
 
 #if KRUNNER_ENABLE_DEPRECATED_SINCE(5, 72)
     /**
@@ -442,13 +454,9 @@ Q_SIGNALS:
     void historyEnabledChanged();
 
 private:
-    Q_PRIVATE_SLOT(d, void scheduleMatchesChanged())
-    Q_PRIVATE_SLOT(d, void matchesChanged())
     Q_PRIVATE_SLOT(d, void jobDone(ThreadWeaver::JobPointer))
-    Q_PRIVATE_SLOT(d, void unblockJobs())
-    Q_PRIVATE_SLOT(d, void runnerMatchingSuspended(bool))
 
-    RunnerManagerPrivate *const d;
+    std::unique_ptr<RunnerManagerPrivate> const d;
 
     friend class RunnerManagerPrivate;
 };
